Breath class

Representa a marca de respiração

Inheritance

Constructors

Breath({required BreathType type})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → BreathType
final
xmlId ↔ String?
Identificador único MEI (xml:id). Opcional; required for elementos referenciados by other via atributos de ligação of the MEI v5.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited