Chord class

Representa a chord (conjunto de notes tocadas simultaneamente)

Inheritance
Mixed-in types

Constructors

Chord({required List<Note> notes, required Duration duration, List<ArticulationType> articulations = const [], TieType? tie, SlurType? slur, BeamType? beam, List<Ornament> ornaments = const [], Dynamic? dynamic, int? voice})

Properties

articulations → List<ArticulationType>
final
beam → BeamType?
final
boundingBox ↔ BoundingBox?
Gets o Hierarchical BoundingBox deste elemento
getter/setter pairinherited
duration → Duration
final
dynamic → Dynamic?
final
hasBoundingBox → bool
Checks if this elemento tem a Hierarchical BoundingBox válido
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
highestNote → Note
no setter
lowestNote → Note
no setter
notes → List<Note>
final
ornaments → List<Ornament>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slur → SlurType?
final
tie → TieType?
final
voice → int?
Number of the voice for notação polifônica (1 = soprano, 2 = contralto, etc.) null = voice única (default)
final
xmlId ↔ String?
Identificador único MEI (xml:id). Opcional; required for elementos referenciados by other via atributos de ligação of the MEI v5.
getter/setter pairinherited

Methods

addBoundingBoxChild(BoundingBox childBBox) → void
Adds a filho to the Hierarchical BoundingBox deste elemento
inherited
clearBoundingBox() → void
Limpa o Hierarchical BoundingBox deste elemento
inherited
getOrCreateBoundingBox() → BoundingBox
Creates and Returns a new Hierarchical BoundingBox for this elemento
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBoundingBoxPosition(double x, double y) → void
Atualiza a position relativa of the BoundingBox
inherited
setBoundingBoxSize(double width, double height) → void
Atualiza o Size of the BoundingBox
inherited
toString() → String
A string representation of this object.
inherited
updateBoundingBoxBounds() → void
ReCalcula recursivamente os bounds of the BoundingBox
inherited
updateBoundingBoxPositions() → void
ReCalcula recursivamente as positions absolutas of the BoundingBox
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited