Duration class

Representa a duração de uma nota ou pausa.

Constructors

Duration(DurationType type, {int dots = 0})
const

Properties

absoluteValue double
Calcula a duração real incluindo pontos de aumento. Fórmula: valor_original + (valor_original * 0.5^1) + (valor_original * 0.5^2) + ...
no setter
dots int
O número de pontos de aumento.
final
hashCode int
The hash code for this object.
no setterinherited
realValue double
Calcula a duração real incluindo pontos de aumento.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type DurationType
O tipo de duração (semibreve, mínima, etc.).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited