Dynamic class

Representa uma indicação dinâmica

Inheritance

Constructors

Dynamic({required DynamicType type, String? customText, bool isHairpin = false, double? length})

Properties

customText String?
final
hashCode int
The hash code for this object.
no setterinherited
isHairpin bool
final
length double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type DynamicType
final
xmlId String?
Identificador único MEI (xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited