FigureAccidental enum

Sinal de alteração de uma figura de baixo cifrado.

Corresponde ao atributo @accid do elemento <f> no MEI v5.

Inheritance
Available extensions

Values

none → const FigureAccidental
sharp → const FigureAccidental
flat → const FigureAccidental
natural → const FigureAccidental
doubleSharp → const FigureAccidental
doubleFlat → const FigureAccidental

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FigureAccidental>
A constant List of the values in this enum, in order of their declaration.