FigureElement class

Representa uma única figura do baixo cifrado, correspondendo ao elemento <f> (figure) dentro de <fb> no MEI v5.

FigureElement(numeral: '6', accidental: FigureAccidental.sharp)
FigureElement(numeral: '4', suffix: FigureSuffix.slash)

Constructors

FigureElement({String? numeral, FigureAccidental accidental = FigureAccidental.none, FigureSuffix suffix = FigureSuffix.none})
const

Properties

accidental FigureAccidental
Alteração aplicada à figura.
final
hashCode int
The hash code for this object.
no setterinherited
numeral String?
Numeral da figura (ex.: "2", "4", "6", "7", "9"). Pode ser null para figuras com apenas acidente.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffix FigureSuffix
Sufixo da figura (extensão, barra, etc.).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited