FigureSuffix enum

Sufixo de figura de baixo cifrado.

Corresponde ao atributo @ext do elemento <f> no MEI v5.

Inheritance
Available extensions

Values

none → const FigureSuffix

Nenhum sufixo

extender → const FigureSuffix

Extensão horizontal (linha de prolongamento)

slash → const FigureSuffix

Barra diagonal descendente (crossing)

tick → const FigureSuffix

Backtick (tick mark)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FigureSuffix>
A constant List of the values in this enum, in order of their declaration.