ChordMember class

Define um membro de um acorde dentro de uma ChordTable (MEI <chordMember>).

Constructors

ChordMember({required int intervalFromRoot, double alter = 0.0})
const

Properties

alter double
Acidente opcional no membro.
final
hashCode int
The hash code for this object.
no setterinherited
intervalFromRoot int
Nota do membro (pname + octave relativo à fundamental, ou semitom).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited