ChordTable class

Tabela de definitions de chords (MEI <chordTable>).

Permite Define vocabulário harmônico reutilizável for análise de chords. Generateslmente armazenada no <meiHead> or <music>.

Constructors

ChordTable({required List<ChordDefinition> definitions})
const

Properties

definitions → List<ChordDefinition>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

findById(String id) → ChordDefinition?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited