HarmonicInterval class

Intervalo harmônico entre duas notas simultâneas (MEI @inth).

Descreve a relação intervalar entre notas de um acorde ou entre vozes.

Constructors

HarmonicInterval({required int semitones, String? diatonicName})
const

Properties

diatonicName String?
Nome diatônico do intervalo (ex.: 'M3', 'm7', 'P5').
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semitones int
Tamanho do intervalo em semitons (0 = uníssono).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited