HarmonicLabel class

Representa uma análise harmônica de uma nota ou acorde (MEI <harm>).

Associado a um evento musical através de xmlId do elemento-alvo.

HarmonicLabel(
  symbol: 'G7',
  scaleDegree: ScaleDegree(degree: 5),
  targetXmlId: 'note1',
)
Inheritance

Constructors

HarmonicLabel({String? symbol, ScaleDegree? scaleDegree, MelodicFunction? melodicFunction, MelodicInterval? melodicInterval, HarmonicInterval? harmonicInterval, String? targetXmlId})

Properties

harmonicInterval HarmonicInterval?
Intervalo harmônico em relação a outra voz.
final
hashCode int
The hash code for this object.
no setterinherited
melodicFunction MelodicFunction?
Função melódica da nota associada.
final
melodicInterval MelodicInterval?
Intervalo melódico desde a nota anterior.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleDegree ScaleDegree?
Grau da escala deste acorde no contexto tonal.
final
symbol String?
Símbolo do acorde (ex.: 'Cmaj7', 'G7', 'Am', 'Bdim').
final
targetXmlId String?
ID do elemento-alvo desta análise (MEI @startid).
final
xmlId String?
Identificador único MEI (xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited