MelodicFunction enum
Função melódica de uma nota (MEI @mfunc).
Baseada na sintaxe Humdrum.
Values
- chordTone → const MelodicFunction
-
Tom de acorde (chord tone)
- passingTone → const MelodicFunction
-
Nota de passagem (passing tone)
- neighborTone → const MelodicFunction
-
Nota de vizinhança / bordadura (neighbor tone)
- escapeTone → const MelodicFunction
-
Escapada (escape tone)
- appoggiatura → const MelodicFunction
-
Appoggiatura
- anticipation → const MelodicFunction
-
Nota de antecipação
- suspension → const MelodicFunction
-
Suspensão
- retardation → const MelodicFunction
-
Retardo
- pedal → const MelodicFunction
-
Pedal
- other → const MelodicFunction
-
Outro / indefinido
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MelodicFunction> - A constant List of the values in this enum, in order of their declaration.