ScaleDegree class

Grau da escala com possível alteração cromática (MEI @deg).

ScaleDegree(degree: 5)          // V
ScaleDegree(degree: 7, alter: -1) // b7 (sétimo abaixado)

Constructors

ScaleDegree({required int degree, double alter = 0.0})
const

Properties

alter double
Alteração cromática do grau (-2.0 a +2.0).
final
degree int
Grau da escala (1–7).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited