KeyMode enum

Modo tonal, conforme o atributo @mode de <staffDef> no MEI v5.

Inheritance
Available extensions

Values

major → const KeyMode
minor → const KeyMode
dorian → const KeyMode
phrygian → const KeyMode
lydian → const KeyMode
mixolydian → const KeyMode
aeolian → const KeyMode
locrian → const KeyMode
none → const KeyMode

Armadura sem modo definido (ex.: música atonal, modal indeterminado)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KeyMode>
A constant List of the values in this enum, in order of their declaration.