Contributor class

Representa a pessoa or organização responsável pela obra or codificação. Correspwhere a <persName> / <corpName> within de <respStmt> no MEI v5.

Constructors

Contributor({required String name, required ResponsibilityRole role, String? identifier})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
identifier → String?
Identificador externo (e.g., VIAF URI, ISNI).
final
name → String
final
role → ResponsibilityRole
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited