EncodingDescription class

Princípios and methods de codificação. Correspwhere a <encodingDesc> no MEI v5.

Constructors

EncodingDescription({String? editorialPrinciples, String meiVersion = '5', List<String> applications = const []})
const

Properties

applications → List<String>
Appliesções used for Generatesr a codificação.
final
editorialPrinciples → String?
Descrição textual dos princípios editoriais.
final
hashCode → int
The hash code for this object.
no setterinherited
meiVersion → String
Version of the MEI used na codificação.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited