FileDescription class

Descrição bibliográfica do arquivo codificado. Corresponde ao elemento <fileDesc> no MEI v5.

<fileDesc> é o único filho obrigatório de <meiHead>.

Constructors

FileDescription({required String title, String? subtitle, List<Contributor> contributors = const [], PublicationStatement? publication, List<SourceDescription> sources = const []})
const

Properties

contributors List<Contributor>
Responsáveis (compositor, arranjador, editor, etc.).
final
hashCode int
The hash code for this object.
no setterinherited
publication PublicationStatement?
Informações de publicação.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sources List<SourceDescription>
Fontes musicais de origem.
final
subtitle String?
Subtítulo (ex.: número de opus, tonalidade).
final
title String
Título principal do arquivo.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited