ManifestationList class
Lista de manifestações (fontes físicas) da obra.
Corresponde a <manifestationList> no MEI v5.
Constructors
-
ManifestationList({required List<
Manifestation> manifestations}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
manifestations
→ List<
Manifestation> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited