MeiHeader class

Cabeçalho MEI completo, correspondendo ao elemento <meiHead> do MEI v5.

Implementa o modelo bibliográfico completo incluindo os quatro níveis FRBR: Work, Expression, Manifestation, Item.

final header = MeiHeader(
  fileDescription: FileDescription(
    title: 'Ave Maria',
    contributors: [Contributor(name: 'Schubert', role: ResponsibilityRole.composer)],
  ),
  encodingDescription: EncodingDescription(
    meiVersion: '5',
    applications: ['flutter_notemus'],
  ),
);

Constructors

MeiHeader({required FileDescription fileDescription, EncodingDescription? encodingDescription, WorkList? workList, ManifestationList? manifestationList, RevisionDescription? revisionDescription})
const

Properties

encodingDescription EncodingDescription?
Descrição da codificação (princípios, aplicações, versão MEI).
final
fileDescription FileDescription
Descrição bibliográfica do arquivo (obrigatório no MEI v5).
final
hashCode int
The hash code for this object.
no setterinherited
manifestationList ManifestationList?
Lista de manifestações (fontes físicas) da obra.
final
revisionDescription RevisionDescription?
Histórico de revisões do arquivo.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workList WorkList?
Lista de obras representadas no arquivo.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited