PublicationStatement class

Descreve a publicação / distribuição of the arquivo codificado. Correspwhere a <pubStmt> within de <fileDesc> no MEI v5.

Constructors

PublicationStatement({String? publisher, String? date, String? place, String? availability})
const

Properties

availability → String?
final
date → String?
final
hashCode → int
The hash code for this object.
no setterinherited
place → String?
final
publisher → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited