RevisionDescription class

Histórico de revisões of the arquivo codificado. Correspwhere a <revisiwheresc> no MEI v5.

Constructors

RevisionDescription({required List<RevisionEntry> entries})
const

Properties

entries → List<RevisionEntry>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited