SourceDescription class

Identifica a fonte musical da qual a codificação foi derivada. Corresponde a <source> dentro de <sourceDesc> no MEI v5.

Constructors

SourceDescription({String? title, String? composer, String? date, String? publisher, String? identifier})
const

Properties

composer String?
final
date String?
final
hashCode int
The hash code for this object.
no setterinherited
identifier String?
final
publisher String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited