MensuralRest class

Pausa em notação mensural (MEI <rest> com dur mensural).

Inheritance

Constructors

MensuralRest({required MensuralDuration duration, int? lines})

Properties

duration MensuralDuration
final
hashCode int
The hash code for this object.
no setterinherited
lines int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xmlId String?
Identificador único MEI (xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited