BeamingMode enum
Modos de beaming para controle fino do agrupamento
Values
- automatic → const BeamingMode
-
Beaming automático baseado na fórmula de compasso (padrão)
- forceFlags → const BeamingMode
-
Forçar flags individuais (sem beams)
- forceBeamAll → const BeamingMode
-
Agrupar todas as notas possíveis em um único beam
- manual → const BeamingMode
-
Beaming manual - usar apenas os grupos explicitamente definidos
- conservative → const BeamingMode
-
Beaming conservador - apenas grupos óbvios (2 notas consecutivas)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BeamingMode> - A constant List of the values in this enum, in order of their declaration.