MusicalElement class abstract

A classe base para todos os elementos em uma partitura.

O campo xmlId é o identificador único MEI (xml:id), usado para referências cruzadas entre elementos (ex.: @startid, @endid, @corresp).

Implementers

Constructors

MusicalElement()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xmlId String?
Identificador único MEI (xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited