slurs property

List<SlurEvent> slurs
final

Concurrent (nested/overlapping) slur boundaries on this note, each with a number so starts and ends can be matched by id. When non-empty this is the source of truth; otherwise slur (a single unnumbered slur) is used.

Implementation

final List<SlurEvent> slurs;