hasMicrotone property
bool
get
hasMicrotone
Returns true if the pitch has a microtonal alteration.
Implementation
bool get hasMicrotone {
return effectiveAlter != effectiveAlter.round().toDouble();
}
Returns true if the pitch has a microtonal alteration.
bool get hasMicrotone {
return effectiveAlter != effectiveAlter.round().toDouble();
}