Rest class

Representa uma pausa.

Inheritance
Mixed-in types

Constructors

Rest({required Duration duration, List<Ornament> ornaments = const []})

Properties

boundingBox ↔ BoundingBox?
Obtém o BoundingBox hierárquico deste elemento
getter/setter pairinherited
duration Duration
final
hasBoundingBox bool
Verifica se este elemento tem um BoundingBox hierárquico válido
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
ornaments List<Ornament>
Lista de ornamentos aplicados à pausa (ex: fermata)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addBoundingBoxChild(BoundingBox childBBox) → void
Adiciona um filho ao BoundingBox hierárquico deste elemento
inherited
clearBoundingBox() → void
Limpa o BoundingBox hierárquico deste elemento
inherited
getOrCreateBoundingBox() → BoundingBox
Cria e retorna um novo BoundingBox hierárquico para este elemento
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBoundingBoxPosition(double x, double y) → void
Atualiza a posição relativa do BoundingBox
inherited
setBoundingBoxSize(double width, double height) → void
Atualiza o tamanho do BoundingBox
inherited
toString() String
A string representation of this object.
inherited
updateBoundingBoxBounds() → void
Recalcula recursivamente os bounds do BoundingBox
inherited
updateBoundingBoxPositions() → void
Recalcula recursivamente as posições absolutas do BoundingBox
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited