PageLayout class

Page layout settings for score rendering

Constructors

PageLayout({double width = 800.0, double height = 1100.0, double marginTop = 80.0, double marginBottom = 80.0, double marginLeft = 80.0, double marginRight = 80.0, double staffGroupSpacing = 12.0, double staffSpacing = 8.0, double systemSpacing = 16.0})
const
PageLayout.a4Landscape()
Factory: A4 page (landscape)
factory
PageLayout.a4Portrait()
Factory: A4 page (portrait)
factory
PageLayout.letter()
Factory: Letter page (US standard)
factory

Properties

contentHeight double
Get content height (excluding margins)
no setter
contentWidth double
Get content width (excluding margins)
no setter
hashCode int
The hash code for this object.
no setterinherited
height double
Page height in pixels (or logical units)
final
marginBottom double
Bottom margin
final
marginLeft double
Left margin
final
marginRight double
Right margin
final
marginTop double
Top margin
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
staffGroupSpacing double
Space between staff groups (in staff spaces)
final
staffSpacing double
Space between staves within a group (in staff spaces)
final
systemSpacing double
Space between systems (in staff spaces)
final
width double
Page width in pixels (or logical units)
final

Methods

copyWith({double? width, double? height, double? marginTop, double? marginBottom, double? marginLeft, double? marginRight, double? staffGroupSpacing, double? staffSpacing, double? systemSpacing}) PageLayout
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited