AdvancedSlur class

Representa uma ligadura de expressão avançada

Inheritance

Constructors

AdvancedSlur({required SlurType type, SlurDirection direction = SlurDirection.auto, int? voiceNumber, String? id})

Properties

direction SlurDirection
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type SlurType
final
voiceNumber int?
final
xmlId String?
Identificador único MEI (xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited