MeasureSpace class
Representa a space de medida inteira (measure completo in siReadsncio),
correspwherendo to the elemento <mSpace> of the MEI v5.
used for indicate a measure de paUses in partes orquestrais where o instrumento not toca, sem display a paUses de semibreve normal.
measure.add(MeasureSpace());
- Inheritance
-
- Object
- MusicalElement
- MeasureSpace
Constructors
- MeasureSpace({int measureCount = 1})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- measureCount → int
-
Number de measures de siReadsncio that this elemento representa.
Default = 1. used for paUsess multi-measures comprimidas.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- xmlId ↔ String?
-
Identificador único MEI (
xml:id). Opcional; required for elementos referenciados by other via atributos de ligação of the MEI v5.getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited