abbreviation property
Short form used from the second system on, e.g. 'Vln. I'
(MusicXML <part-abbreviation>, MEI <labelAbbr>).
Implementation
final String? abbreviation;
Short form used from the second system on, e.g. 'Vln. I'
(MusicXML <part-abbreviation>, MEI <labelAbbr>).
final String? abbreviation;