chromatic property
Semitones to add to the written pitch to obtain the sounding pitch, EXCLUDING octaveChange.
Implementation
final int chromatic;
Semitones to add to the written pitch to obtain the sounding pitch, EXCLUDING octaveChange.
final int chromatic;