connectBarlines property
Whether barlines should connect all staves in the group
Default: true for all bracket types except BracketType.none
Implementation
final bool connectBarlines;
Whether barlines should connect all staves in the group
Default: true for all bracket types except BracketType.none
final bool connectBarlines;