TabDurSym class

Símbolo de duração em tablatura (MEI <tabDurSym>).

Em tablatura, a duração pode ser indicada por um símbolo separado acima ou abaixo dos números de casa. Corresponde ao elemento <tabDurSym> do MEI v5.

Inheritance

Constructors

TabDurSym({required Duration duration, bool above = true})

Properties

above bool
Indica se o símbolo é exibido acima (padrão) ou abaixo das cordas.
final
duration Duration
Duração representada por este símbolo.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xmlId String?
Identificador único MEI (xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited