TabNote class

Representa uma nota em tablatura, correspondendo ao elemento <note> com atributos @tab.fret e @tab.string no MEI v5.

TabNote(string: 1, fret: 0)   // primeira corda solta
TabNote(string: 3, fret: 2)   // terceira corda, 2ª casa
TabNote(string: 6, fret: 5)   // sexta corda, 5ª casa
Inheritance

Constructors

TabNote({required int string, required int fret, Duration? duration, bool isHarmonic = false, bool isMuted = false})

Properties

duration Duration?
Duração da nota de tablatura.
final
fret int
Casa (fret). 0 = corda solta. MEI @tab.fret.
final
hashCode int
The hash code for this object.
no setterinherited
isHarmonic bool
Indica se esta nota é harmonics (toque levemente a corda).
final
isMuted bool
Indica se há mudo (x) nesta corda.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
string int
Número da corda (1 = mais aguda). MEI @tab.string.
final
xmlId String?
Identificador único MEI (xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited