TabString class

Representa a afinação de uma corda em notação de tablatura.

Corresponde às informações de afinação em <staffDef> no MEI v5.

Constructors

TabString({required int number, required String pitchName, required int octave})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
number int
Número da corda (1 = mais aguda / primeira corda).
final
octave int
Oitava da corda solta.
final
pitchName String
Nome da nota da corda solta (ex.: 'E', 'A', 'D', 'G', 'B').
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited