TabTuning class

Afinação de instrumento para tablatura.

Inclui afinações pré-definidas para violão, baixo e outros instrumentos.

Constructors

TabTuning({required String name, required List<TabString> strings})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Nome da afinação (ex.: 'Standard', 'Drop D', 'Open G').
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strings List<TabString>
Cordas da afinação, ordenadas da mais aguda (1) para a mais grave.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

bassStandard → const TabTuning
Afinação padrão de baixo de 4 cordas (E1-A1-D2-G2).
guitarDropD → const TabTuning
Afinação Drop D de violão (D2-A2-D3-G3-B3-E4).
guitarStandard → const TabTuning
Afinação padrão de violão (E2-A2-D3-G3-B3-E4).
luteStandard → const TabTuning
Afinação padrão de alaúde renascentista em Sol (G2-C3-F3-A3-D4-G4).