NoteTechnique enum

Técnicas específicas de nota

Inheritance
Available extensions

Values

harmonic → const NoteTechnique
glissando → const NoteTechnique
tremolo → const NoteTechnique
bend → const NoteTechnique
slide → const NoteTechnique
vibrato → const NoteTechnique
tapping → const NoteTechnique
hammer → const NoteTechnique
pullOff → const NoteTechnique
pinchHarmonic → const NoteTechnique
artificialHarmonic → const NoteTechnique
palmMute → const NoteTechnique
deadNote → const NoteTechnique
ghost → const NoteTechnique
chokeSymbol → const NoteTechnique
damp → const NoteTechnique
dampAll → const NoteTechnique
openRim → const NoteTechnique
closedRim → const NoteTechnique

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NoteTechnique>
A constant List of the values in this enum, in order of their declaration.