TempoMark class

Representa uma indicação de tempo/andamento

Inheritance

Constructors

TempoMark({required DurationType beatUnit, int? bpm, String? text, bool showMetronome = true})

Properties

beatUnit DurationType
final
bpm int?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showMetronome bool
final
text String?
final
xmlId String?
Identificador único MEI (xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited