MusicText class

Representa texto musical

Inheritance

Constructors

MusicText({required String text, required TextType type, TextPlacement placement = TextPlacement.above, String? fontFamily, double? fontSize, bool? bold, bool? italic})

Properties

bold bool?
final
fontFamily String?
final
fontSize double?
final
hashCode int
The hash code for this object.
no setterinherited
italic bool?
final
placement TextPlacement
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
type TextType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited