Verse class

Representa um verso de letra, correspondendo ao elemento <verse> do MEI v5.

Suporta múltiplos versos numerados (@n) com sílabas Syllable individuais.

Verse(
  number: 1,
  syllables: [
    Syllable(text: 'A-', type: SyllableType.initial),
    Syllable(text: 've', type: SyllableType.terminal),
  ],
)
Inheritance

Constructors

Verse({int number = 1, required List<Syllable> syllables, String? language})

Properties

hashCode int
The hash code for this object.
no setterinherited
language String?
Idioma do verso (MEI @xml:lang), ex.: 'la', 'pt', 'en'.
final
number int
Número do verso (MEI @n). Padrão = 1.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syllables List<Syllable>
Sílabas deste verso.
final
xmlId String?
Identificador único MEI (xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited