AdditiveMeterGroup class

Um grupo aditivo dentro de uma fórmula de compasso aditiva.

Fórmulas como (3+2+2)/8 são representadas como uma lista de AdditiveMeterGroup onde cada grupo tem um numerator e compartilha o mesmo denominator da TimeSignature pai.

Corresponde ao elemento <meterSigGrp> do MEI v5 quando aplicado a fórmulas aditivas.

Constructors

AdditiveMeterGroup(int numerator)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
numerator int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited