TupletRatio class

Razão de uma quiáltera

Constructors

TupletRatio(int actualNotes, int normalNotes)
const

Properties

actualNotes int
final
hashCode int
The hash code for this object.
no setterinherited
modifier double
Modificador que será aplicado às durações Fórmula: normalNotes / actualNotes
no setter
normalNotes int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited