voices property
Collection of voices (order not guaranteed).
Kept as a convenience for iteration and collection queries; use sortedVoices when voice order matters.
Implementation
Iterable<Voice> get voices => _voicesByNumber.values;
Collection of voices (order not guaranteed).
Kept as a convenience for iteration and collection queries; use sortedVoices when voice order matters.
Iterable<Voice> get voices => _voicesByNumber.values;