hasOpenEnd property

bool hasOpenEnd
final

Whether the bracket has an open right end (no closing vertical line).

Defaults to false (closed bracket with a vertical line on the right).

Implementation

final bool hasOpenEnd;