MidiGenerationOptions class

Constructors

MidiGenerationOptions({int ticksPerQuarter = 960, int defaultBpm = 120, int repeatDefaultTimes = 2, int maxRepeatCycles = 16, bool includeMetronome = false, int metronomeChannel = 9, int metronomeAccentNote = 76, int metronomeRegularNote = 77, int metronomeAccentVelocity = 120, int metronomeRegularVelocity = 95, int metronomeClickDurationTicks = 120, bool playGraceNotes = true, double graceDurationScale = 0.25, MidiInstrumentAssignment defaultInstrument = const MidiInstrumentAssignment(channel: 0, program: 0, velocity: 96), Map<int, MidiInstrumentAssignment> instrumentsByStaff = const <int, MidiInstrumentAssignment>{}})
const

Properties

defaultBpm int
final
defaultInstrument MidiInstrumentAssignment
final
graceDurationScale double
final
hashCode int
The hash code for this object.
no setterinherited
includeMetronome bool
final
instrumentsByStaff Map<int, MidiInstrumentAssignment>
final
maxRepeatCycles int
final
metronomeAccentNote int
final
metronomeAccentVelocity int
final
metronomeChannel int
final
metronomeClickDurationTicks int
final
metronomeRegularNote int
final
metronomeRegularVelocity int
final
playGraceNotes bool
final
repeatDefaultTimes int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ticksPerQuarter int
final

Methods

copyWith({int? ticksPerQuarter, int? defaultBpm, int? repeatDefaultTimes, int? maxRepeatCycles, bool? includeMetronome, int? metronomeChannel, int? metronomeAccentNote, int? metronomeRegularNote, int? metronomeAccentVelocity, int? metronomeRegularVelocity, int? metronomeClickDurationTicks, bool? playGraceNotes, double? graceDurationScale, MidiInstrumentAssignment? defaultInstrument, Map<int, MidiInstrumentAssignment>? instrumentsByStaff}) MidiGenerationOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited