MidiInstrumentAssignment class

Constructors

MidiInstrumentAssignment({required int channel, required int program, int velocity = 96})
const

Properties

channel int
final
hashCode int
The hash code for this object.
no setterinherited
program int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
velocity int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited