Beam class

Representa uma viga (beam) que conecta notas

Inheritance

Constructors

Beam({required List<Note> notes, int beamCount = 1, bool primary = true})

Properties

beamCount int
final
hashCode int
The hash code for this object.
no setterinherited
notes List<Note>
final
primary bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited