Chord class

Representa um acorde (conjunto de notas tocadas simultaneamente)

Inheritance
Mixed-in types

Constructors

Chord({required List<Note> notes, required Duration duration, List<ArticulationType> articulations = const [], TieType? tie, SlurType? slur, BeamType? beam, List<Ornament> ornaments = const [], Dynamic? dynamic, int? voice})

Properties

articulations List<ArticulationType>
final
beam BeamType?
final
boundingBox ↔ BoundingBox?
Obtém o BoundingBox hierárquico deste elemento
getter/setter pairinherited
duration Duration
final
dynamic Dynamic?
final
hasBoundingBox bool
Verifica se este elemento tem um BoundingBox hierárquico válido
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
highestNote Note
no setter
lowestNote Note
no setter
notes List<Note>
final
ornaments List<Ornament>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slur SlurType?
final
tie TieType?
final
voice int?
Número da voz para notação polifônica (1 = soprano, 2 = contralto, etc.) null = voz única (padrão)
final
xmlId String?
Identificador único MEI (xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.
getter/setter pairinherited

Methods

addBoundingBoxChild(BoundingBox childBBox) → void
Adiciona um filho ao BoundingBox hierárquico deste elemento
inherited
clearBoundingBox() → void
Limpa o BoundingBox hierárquico deste elemento
inherited
getOrCreateBoundingBox() → BoundingBox
Cria e retorna um novo BoundingBox hierárquico para este elemento
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBoundingBoxPosition(double x, double y) → void
Atualiza a posição relativa do BoundingBox
inherited
setBoundingBoxSize(double width, double height) → void
Atualiza o tamanho do BoundingBox
inherited
toString() String
A string representation of this object.
inherited
updateBoundingBoxBounds() → void
Recalcula recursivamente os bounds do BoundingBox
inherited
updateBoundingBoxPositions() → void
Recalcula recursivamente as posições absolutas do BoundingBox
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited