Clef class

Representa uma clave no início de uma pauta.

Inheritance

Constructors

Clef({ClefType clefType = ClefType.treble, int? staffPosition, String? type})

Properties

actualClefType ClefType
Getter para o tipo de clave atual
no setter
clefType ClefType
final
glyphName String
Retorna o glifo SMuFL correspondente à clave
no setter
hashCode int
The hash code for this object.
no setterinherited
octaveShift int
Retorna o deslocamento de oitava aplicado pela clave
no setter
referenceLineOffsetSmufl double
Obtém a posição vertical da linha de referência da clave no pentagrama conforme especificações SMuFL (em unidades staff space)
no setter
referenceLinePosition int
Retorna a posição da linha de referência da clave no pentagrama (0 = linha central, positivo = acima, negativo = abaixo)
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
staffPosition int?
final
type String
Backward compatibility - DEPRECATED: Use actualClefType instead
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited