Cluster class

Representa um cluster (grupo de notas adjacentes tocadas simultaneamente)

Inheritance

Constructors

Cluster({required Pitch lowestPitch, required Pitch highestPitch, Pitch? lowestNote, Pitch? highestNote, ClusterType type = ClusterType.chromatic, String? notation, bool showBracket = true})

Properties

glyphName String
Retorna o glifo SMuFL apropriado
no setter
hashCode int
The hash code for this object.
no setterinherited
highestNote Pitch
final
highestPitch Pitch
final
lowestNote Pitch
final
lowestPitch Pitch
final
notation String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBracket bool
final
type ClusterType
final
xmlId String?
Identificador único MEI (xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited