FigureElement class
Representa a única figure of the bottom cifrado, correspwherendo to the
elemento <f> (figure) within de <fb> no MEI v5.
FigureElement(numeral: '6', accidental: FigureAccidental.sharp)
FigureElement(numeral: '4', suffix: FigureSuffix.slash)
Constructors
- FigureElement({String? numeral, FigureAccidental accidental = FigureAccidental.none, FigureSuffix suffix = FigureSuffix.none})
-
const
Properties
- accidental → FigureAccidental
-
Alteração Applied to the figure.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- numeral → String?
-
Numeral of the figure (e.g., "2", "4", "6", "7", "9"). Can be null for
figures with only accidental.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suffix → FigureSuffix
-
Sufixo of the figure (extension, barra, etc.).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited