FiguredBass class
Representa uma indicação de baixo cifrado (thoroughbass / figured bass),
correspondendo ao elemento <fb> (figured bass) do MEI v5.
O baixo cifrado é uma convenção de notação barroca onde números e acidentes acima ou abaixo de uma nota de baixo indicam quais harmonias devem ser realizadas pelo instrumentista.
FiguredBass(
figures: [
FigureElement(numeral: '6'),
FigureElement(numeral: '4', accidental: FigureAccidental.sharp),
],
)
- Inheritance
-
- Object
- MusicalElement
- FiguredBass
Constructors
-
FiguredBass({required List<
FigureElement> figures, bool above = false})
Properties
- above → bool
-
Indica se a realização deve ser exibida acima da nota (padrão = abaixo).
final
-
figures
→ List<
FigureElement> -
Figuras do baixo cifrado, de cima para baixo.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- xmlId ↔ String?
-
Identificador único MEI (
xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited