ChordDefinition class
Define um tipo de acorde na tabela de acordes (MEI <chordDef>).
ChordDefinition(
id: 'maj',
label: 'Major',
members: [ChordMember(0), ChordMember(4), ChordMember(7)],
)
Constructors
-
ChordDefinition({required String id, required String label, required List<
ChordMember> members}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Identificador único do acorde (MEI
xml:idem<chordDef>).final - label → String
-
Rótulo descritivo (ex.: 'Major', 'Minor 7th').
final
-
members
→ List<
ChordMember> -
Membros do acorde (intervalos em semitons a partir da fundamental).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited