ChordTable class

Tabela de definições de acordes (MEI <chordTable>).

Permite definir vocabulário harmônico reutilizável para análise de acordes. Geralmente armazenada no <meiHead> ou <music>.

Constructors

ChordTable({required List<ChordDefinition> definitions})
const

Properties

definitions List<ChordDefinition>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

findById(String id) ChordDefinition?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited