MelodicInterval class
Intervalo melódico entre duas notas consecutivas (MEI @intm).
MelodicInterval.diatonic('M2') // segunda maior
MelodicInterval.semitones(3) // 3 semitons (terça menor)
MelodicInterval.parsons('U') // ascendente (Código de Parsons)
Constructors
- MelodicInterval.diatonic(String value)
-
Intervalo diatônico (ex.: 'M2', 'm3', 'P4', 'P5', 'M6', 'm7', 'P8').
factory
- MelodicInterval.parsons(String code)
-
Código de Parsons: 'R' (repetição), 'U' (ascendente), 'D' (descendente).
factory
- MelodicInterval.semitones(int value)
-
Intervalo em semitons (positivo = ascendente, negativo = descendente).
factory
Properties
- diatonicValue → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- parsonsValue → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semitonesValue → int?
-
final
- type → MelodicIntervalType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited