KeySignature class
Representa a armadura de clave.
- Inheritance
-
- Object
- MusicalElement
- KeySignature
Constructors
- KeySignature(int count, {int? previousCount})
Properties
- count → int
-
Número de sustenidos (positivo) ou bemóis (negativo).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- previousCount → int?
-
Contagem da armadura anterior (para renderizar naturais de cancelamento).
Positivo = sustenidos anteriores, negativo = bemóis anteriores.
null = nenhum cancelamento necessário.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited