Line class

Representa uma linha de prolongamento

Inheritance

Constructors

Line({required LineType type, required double startX, required double startY, required double endX, required double endY, String? text, bool showArrow = false})

Properties

endX double
final
endY double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showArrow bool
final
startX double
final
startY double
final
text String?
final
type LineType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited