defaultVoice constant
int
const defaultVoice
Voice number attributed to elements that do not declare one.
Note.voice == null and Chord.voice == null mean "the only voice",
which by convention is voice 1. Rests, tuplets and every element without
a voice field are attributed to this voice as well.
Implementation
static const int defaultVoice = 1;