Manifestation class
Nível FRBR: Manifestação — fonte física that encarna a obra.
Correspwhere a <manifestation> within de <manifestationList> no MEI v5.
Constructors
Properties
- date → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String?
-
final
- location → String?
-
final
- medium → String?
-
Type físico: manuscript, print, digital, etc.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
final
- type → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited