Manifestation class

Nível FRBR: Manifestação — fonte física que encarna a obra. Corresponde a <manifestation> dentro de <manifestationList> no MEI v5.

Constructors

Manifestation({String? title, String? type, String? medium, String? date, String? location, String? identifier})
const

Properties

date String?
final
hashCode int
The hash code for this object.
no setterinherited
identifier String?
final
location String?
final
medium String?
Tipo físico: manuscript, print, digital, etc.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited