WorkInfo class
Informações musicais sobre a obra (FRBR Work level).
Corresponde a <work> dentro de <workList> no MEI v5.
Constructors
Properties
- composer → String?
-
final
- date → String?
-
final
- genre → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String?
-
final
- meter → String?
-
final
- opusNumber → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tempo → String?
-
final
- title → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited