Ligature class
Ligatura mensural (MEI <ligature>).
Uma ligatura é um grupo de notas escritas ligadas graficamente, comum na notação medieval. A forma gráfica codifica as durações implicitamente.
Ligature(
notes: [
MensuralNote(pitchName: 'G', octave: 4, duration: MensuralDuration.breve),
MensuralNote(pitchName: 'A', octave: 4, duration: MensuralDuration.longa),
],
form: LigatureForm.cumpropriete,
)
- Inheritance
-
- Object
- MusicalElement
- Ligature
Constructors
-
Ligature({required List<
MensuralNote> notes, LigatureForm form = LigatureForm.cumpropriete})
Properties
- form → LigatureForm
-
Forma gráfica da ligatura.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
notes
→ List<
MensuralNote> -
Notas que compõem a ligatura.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- xmlId ↔ String?
-
Identificador único MEI (
xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited