MensuralDuration enum
Valor mensural de uma nota (MEI dur em contexto mensural).
Values
- maxima → const MensuralDuration
-
Maxima (Mx)
- longa → const MensuralDuration
-
Longa (L)
- breve → const MensuralDuration
-
Breve (B)
- semibreve → const MensuralDuration
-
Semibreve (Sb)
- minima → const MensuralDuration
-
Mínima (Mn)
- semiminima → const MensuralDuration
-
Semimínima (Sm)
- fusa → const MensuralDuration
-
Fusa (Fu)
- semifusa → const MensuralDuration
-
Semifusa (Sf)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MensuralDuration> - A constant List of the values in this enum, in order of their declaration.