ProportMark class

Proporção mensural (MEI <proport>).

Indica uma mudança de proporção rítmica (ex.: sesquialtera 3:2, dupla proporção 2:1).

ProportMark(num: 3, numbase: 2)  // Sesquialtera (3:2)
ProportMark(num: 2, numbase: 1)  // Dupla proporção
Inheritance

Constructors

ProportMark({required int num, required int numbase})

Properties

hashCode int
The hash code for this object.
no setterinherited
modifier double
Retorna o modificador de duração (numbase / num).
no setter
num int
Numerador da proporção.
final
numbase int
Denominador da proporção.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xmlId String?
Identificador único MEI (xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited