ProportMark class

Proporção mensural (MEI <proport>).

Indicates a mudança de proporção rhythmic (e.g., sesquialtera 3:2, dupla proporção 2:1).

ProportMark(num: 3, numbase: 2)  // Sesquialtera (3:2)
ProportMark(num: 2, numbase: 1)  // Dupla proporção
Inheritance

Constructors

ProportMark({required int num, required int numbase})

Properties

hashCode int
The hash code for this object.
no setterinherited
modifier double
Returns o modificador de duração (numbase / num).
no setter
num int
Numerator of the proporção.
final
numbase int
Denominator of the proporção.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xmlId String?
Identificador único MEI (xml:id). Opcional; required for elementos referenciados by other via atributos de ligação of the MEI v5.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited