BeamingMode enum

Modos de beaming for control fino of the agrupamento

Inheritance
Available extensions

Values

automatic → const BeamingMode

Beaming automático based na fórmula de measure (default)

forceFlags → const BeamingMode

Forçar flags individuais (sem beams)

forceBeamAll → const BeamingMode

Agrupar all as notes possible in a único beam

manual → const BeamingMode

Beaming manual - Use only os grupos explicitamente definidos

conservative → const BeamingMode

Beaming conservador - only grupos óbvios (2 notes consecutivas)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BeamingMode>
A constant List of the values in this enum, in order of their declaration.