SlurEvent class

A single numbered slur boundary on a note, enabling concurrent (nested/overlapping) slurs distinguished by number (MusicXML <slur number=> / MEI @startid/@endid).

Constructors

SlurEvent({required int number, required SlurType type})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
number int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type SlurType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited