NcForm enum
Forma do componente de neuma (MEI @nc.form ou @form em <nc>).
Cada forma corresponde a um tipo específico de neuma simples ou ornamental.
Values
- punctum → const NcForm
-
Ponto simples (punctum)
- virga → const NcForm
-
Virga (ponto com haste ascendente)
- quilisma → const NcForm
-
Quilisma (nota oscilante)
- oriscus → const NcForm
-
Oriscus
- stropha → const NcForm
-
Stropha
- liquescentAscending → const NcForm
-
Liquescência ascendente
- liquescentDescending → const NcForm
-
Liquescência descendente
- connected → const NcForm
-
Forma conectada (ligado a nota seguinte)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited