Neume class
Representa um neuma completo (MEI <neume>).
Um neuma é um grupo de sons (componentes) que formam uma unidade rítmico- melódica na notação gregoriana. Corresponde a uma ou mais sílabas de texto.
Neume(
type: NeumeType.pes,
components: [
NeumeComponent(pitchName: 'F', octave: 3, form: NcForm.punctum),
NeumeComponent(pitchName: 'G', octave: 3, form: NcForm.virga),
],
)
- Inheritance
-
- Object
- MusicalElement
- Neume
Constructors
-
Neume({required NeumeType type, required List<
NeumeComponent> components, String? syllable, NeumeNotationStyle notationStyle = NeumeNotationStyle.square})
Properties
-
components
→ List<
NeumeComponent> -
Componentes do neuma, em ordem de performance.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- notationStyle → NeumeNotationStyle
-
Indica a tradição de notação (quadrada, adiastemática, etc.).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- syllable → String?
-
Sílaba de texto associada (letra do canto).
final
- type → NeumeType
-
Tipo de neuma.
final
- xmlId ↔ String?
-
Identificador único MEI (
xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited