NeumeAccidental enum
Acidente cromático aplicado a a posição de pauta no canto (sinal autônomo, colocado antes das notes que governa — persiste até a próxima divisória/ palavra). O bemol no si é o mais comum.
Values
- none → const NeumeAccidental
-
Sem acidente.
- flat → const NeumeAccidental
-
Bemol (♭) — GABC
x. - natural → const NeumeAccidental
-
Bequadro (♮) — GABC
y. -
Sustenido (♯) — GABC
#.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NeumeAccidental> - A constant List of the values in this enum, in order of their declaration.