NeumeComponent class
Representa um componente individual de neuma (MEI <nc> — neume component).
Um neume component é a unidade mínima de uma figura de neuma, equivalente aproximadamente a uma nota em CMN. Pode ter altura (se adiastemático com linhas guia, ou em notação quadrada com pauta).
NeumeComponent(
pitchName: 'G',
octave: 3,
form: NcForm.punctum,
)
Constructors
- NeumeComponent({String? pitchName, int? octave, NcForm form = NcForm.punctum, NeumeInterval? interval, bool isLiquescent = false, bool connected = false})
-
const
Properties
- connected → bool
-
Indica conexão com o próximo componente (ligature graphique).
final
- form → NcForm
-
Forma gráfica do componente.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interval → NeumeInterval?
-
Direção do intervalo em relação ao componente anterior.
final
- isLiquescent → bool
-
Indica se este componente é liquescente.
final
- octave → int?
-
Oitava da nota.
final
- pitchName → String?
-
Nome da nota (C–B), se a notação é diastema (com altura definida).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited