NeumeComponent class

Representa a componente individual de neuma (MEI <nc> — neume component).

A neume component is a unidade mínima de a figure de neuma, equivalente aproximadamente a a note in CMN. Can ter height (if adiastemático with lines guia, or in noteção quadrada with staff).

NeumeComponent(
  pitchName: 'G',
  octave: 3,
  form: NcForm.punctum,
)

Constructors

NeumeComponent({String? pitchName, int? octave, NcForm form = NcForm.punctum, NeumeInterval? interval, bool isLiquescent = false, bool connected = false})
const

Properties

connected bool
Indicates conexão with o next componente (ligature graphique).
final
form NcForm
Forma gráfica of the componente.
final
hashCode int
The hash code for this object.
no setterinherited
interval NeumeInterval?
Direction of the intervalo in relação to the componente previous.
final
isLiquescent bool
Indicates if this componente is liquescente.
final
octave int?
Oitava of the note.
final
pitchName String?
Name of the note (C–B), if a noteção is diastema (with height definida).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited