NeumeDivision class
Indicates a divisão between palavras / respiração no canto gregoriano.
Correspwhere to the elemento <division> of the MEI v5.
- Inheritance
-
- Object
- MusicalElement
- NeumeDivision
Constructors
- NeumeDivision({NeumeDivisionType type = NeumeDivisionType.minima})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → NeumeDivisionType
-
Type de divisão (respiração between syllables).
final
- xmlId ↔ String?
-
Identificador único MEI (
xml:id). Opcional; required for elementos referenciados by other via atributos de ligação of the MEI v5.getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited