NeumeNotationStyle enum
Estilo de notação de neuma.
Values
- square → const NeumeNotationStyle
-
Notação quadrada (notação gregoriana com pauta, séc. XII em diante)
- adiastematic → const NeumeNotationStyle
-
Notação adiastemática (sans pauta, apenas direção melódica)
- hufnagel → const NeumeNotationStyle
-
Notação neumática alemã (Hufnagel)
- aquitanian → const NeumeNotationStyle
-
Notação aquitana (pontos sobre linha)
- beneventan → const NeumeNotationStyle
-
Notação beneventana
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NeumeNotationStyle> - A constant List of the values in this enum, in order of their declaration.