Note class

Representa uma nota musical com altura e duração.

Inheritance
Mixed-in types

Constructors

Note({required Pitch pitch, required Duration duration, BeamType? beam, List<ArticulationType> articulations = const [], TieType? tie, SlurType? slur, List<Ornament> ornaments = const [], Dynamic? dynamicElement, List<PlayingTechnique> techniques = const [], int? voice, int tremoloStrokes = 0, bool isGraceNote = false, Pitch? alternatePitch, int? tabFret, int? tabString})

Properties

alternatePitch Pitch?
Altura alternativa para grace notes com uma altura específica
final
articulations List<ArticulationType>
final
beam BeamType?
final
boundingBox ↔ BoundingBox?
Obtém o BoundingBox hierárquico deste elemento
getter/setter pairinherited
duration Duration
final
dynamicElement Dynamic?
Dinâmica específica da nota
final
hasBoundingBox bool
Verifica se este elemento tem um BoundingBox hierárquico válido
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isGraceNote bool
Indica se esta nota é uma grace note (nota de ornamento)
final
isTabNote bool
Indica se esta nota é de tablatura (possui tabFret ou tabString).
no setter
ornaments List<Ornament>
Lista de ornamentos aplicados à nota
final
pitch Pitch
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slur SlurType?
Opcional: Define se esta nota inicia ou termina uma ligadura de expressão.
final
tabFret int?
Casa (fret) na tablatura. null = nota não é de tablatura. Corresponde ao atributo @tab.fret do MEI v5. 0 = corda solta (open string), 1–24 = casas numeradas.
final
tabString int?
Número da corda na tablatura (1-based, corda mais aguda = 1). Corresponde ao atributo @tab.string do MEI v5.
final
techniques List<PlayingTechnique>
Técnicas especiais da nota
final
tie TieType?
final
tremoloStrokes int
Número de traços de tremolo (0 = nenhum, 1-5 = número de traços)
final
voice int?
Número da voz para notação polifônica (1 = soprano, 2 = contralto, etc.) null = voz única (padrão)
final
xmlId String?
Identificador único MEI (xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.
getter/setter pairinherited

Methods

addBoundingBoxChild(BoundingBox childBBox) → void
Adiciona um filho ao BoundingBox hierárquico deste elemento
inherited
clearBoundingBox() → void
Limpa o BoundingBox hierárquico deste elemento
inherited
getOrCreateBoundingBox() → BoundingBox
Cria e retorna um novo BoundingBox hierárquico para este elemento
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBoundingBoxPosition(double x, double y) → void
Atualiza a posição relativa do BoundingBox
inherited
setBoundingBoxSize(double width, double height) → void
Atualiza o tamanho do BoundingBox
inherited
toString() String
A string representation of this object.
inherited
updateBoundingBoxBounds() → void
Recalcula recursivamente os bounds do BoundingBox
inherited
updateBoundingBoxPositions() → void
Recalcula recursivamente as posições absolutas do BoundingBox
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited