OctaveMark class

Marca de oitava (8va, 8vb, 15ma, etc.)

Inheritance

Constructors

OctaveMark({required OctaveType type, required int startMeasure, required int endMeasure, int? startNote, int? endNote, double length = 100.0, bool showBracket = true})

Properties

endMeasure int
final
endNote int?
final
hashCode int
The hash code for this object.
no setterinherited
length double
final
octaveShift int
Retorna o deslocamento em oitavas
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBracket bool
final
startMeasure int
final
startNote int?
final
text String
Retorna o texto da marca
no setter
type OctaveType
final
xmlId String?
Identificador único MEI (xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited