Ornament class
Representa um ornamento musical
- Inheritance
-
- Object
- MusicalElement
- Ornament
Constructors
- Ornament({required OrnamentType type, bool above = true, String? text, Pitch? alternatePitch})
Properties
- above → bool
-
final
- alternatePitch → Pitch?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
final
- type → OrnamentType
-
final
- xmlId ↔ String?
-
Identificador único MEI (
xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited