PitchUtils class
Classe utilitária para operações com alturas
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromMidiNumber(
int midiNumber, {AccidentalType preferredAccidental = AccidentalType.sharp}) → Pitch - Converte um número MIDI para Pitch
-
intervalInSemitones(
Pitch pitch1, Pitch pitch2) → double - Calcula o intervalo em semitons entre duas alturas
-
transpose(
Pitch pitch, double semitones) → Pitch - Transpõe uma altura por um número de semitons