PitchUtils class
Utility class for pitch operations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromMidiNumber(
int midiNumber, {AccidentalType preferredAccidental = AccidentalType.sharp}) → Pitch - Converts a MIDI number to a Pitch.
-
intervalInSemitones(
Pitch pitch1, Pitch pitch2) → double - calculateTestes the interval in semitones between two pitches.
-
transpose(
Pitch pitch, double semitones) → Pitch - Transposes a pitch by a number of semitones.