Staff class

Representa uma pauta, que contém compassos.

Constructors

Staff()

Properties

hashCode int
The hash code for this object.
no setterinherited
measures List<Measure>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(Measure measure) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited