Staff constructor

Staff({
  1. List<Measure>? measures,
})

Creates a Staff with the given measures list.

If measures is omitted an empty list is used, and measures can be added later via add.

Implementation

Staff({List<Measure>? measures}) : measures = measures ?? [];