BracketRenderConfig class
Configuration for bracket/brace rendering
Constructors
- BracketRenderConfig({double thickness = 0.16, double tipWidth = 0.5, double horizontalOffset = 1.0, String? glyphName})
-
const
- BracketRenderConfig.brace()
-
Factory: Configuration for brace { rendering
factory
- BracketRenderConfig.bracket()
-
Factory: Configuration for bracket [ rendering
factory
- BracketRenderConfig.line()
-
Factory: Configuration for line | rendering
factory
Properties
- glyphName → String?
-
SMuFL glyph names for bracket/brace rendering
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalOffset → double
-
Horizontal offset from staff (in staff spaces)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thickness → double
-
Thickness of bracket/brace lines (in staff spaces)
final
- tipWidth → double
-
Width of bracket tips (in staff spaces)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited