TabDurSym class

Symbol de duração in tablatura (MEI <tabDurSym>).

in tablatura, a duração can be indicada by a symbol separate above or below dos numbers de casa. Correspwhere to the elemento <tabDurSym> of the MEI v5.

Inheritance

Constructors

TabDurSym({required Duration duration, bool above = true})

Properties

above bool
Indicates if o symbol is displayed above (default) or below das cordas.
final
duration Duration
Duração representada by this symbol.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xmlId String?
Identificador único MEI (xml:id). Opcional; required for elementos referenciados by other via atributos de ligação of the MEI v5.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited