TabGrp class
Grupo de notas simultâneas em tablatura (MEI <tabGrp>).
Equivale a um acorde em notação convencional, mas representado como números de casa em múltiplas cordas simultaneamente.
TabGrp(
notes: [
TabNote(string: 1, fret: 0),
TabNote(string: 2, fret: 1),
TabNote(string: 3, fret: 2),
],
duration: Duration(DurationType.quarter),
)
- Inheritance
-
- Object
- MusicalElement
- TabGrp
Properties
- duration → Duration
-
Duração do grupo.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
notes
→ List<
TabNote> -
Notas do grupo (uma por corda).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- xmlId ↔ String?
-
Identificador único MEI (
xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited