TabGrp class
Grupo de notes simultâneas in tablatura (MEI <tabGrp>).
Equivale a a chord in noteção convencional, mas representado as numbers de casa in múltiplas cordas simultaneamente.
TabGrp(
notes: [
TabNote(string: 1, fret: 0),
TabNote(string: 2, fret: 1),
TabNote(string: 3, fret: 2),
],
duration: Duration(DurationType.quarter),
)
- Inheritance
-
- Object
- MusicalElement
- TabGrp
Properties
- duration → Duration
-
Duração of the grupo.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
notes
→ List<
TabNote> -
Notes of the grupo (a by corda).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- xmlId ↔ String?
-
Identificador único MEI (
xml:id). Opcional; required for elementos referenciados by other via atributos de ligação of the MEI v5.getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited