TabTuning class

Afinação de instrumento for tablatura.

Includes afinações pré-definidas for violão, bottom and other instrumentos.

Constructors

TabTuning({required String name, required List<TabString> strings})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Name of the afinação (e.g., 'Standard', 'Drop D', 'Open G').
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strings List<TabString>
Cordas of the afinação, ordenadas of the more aguda (1) for a more grave.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

bassStandard → const TabTuning
Afinação default de bottom de 4 cordas (E1-A1-D2-G2).
guitarDropD → const TabTuning
Afinação Drop D de violão (D2-A2-D3-G3-B3-E4).
guitarStandard → const TabTuning
Afinação default de violão (E2-A2-D3-G3-B3-E4).
luteStandard → const TabTuning
Afinação default de alaúde renascentista in Sol (G2-C3-F3-A3-D4-G4).