PlayingTechnique class
Representa uma técnica de execução
- Inheritance
-
- Object
- MusicalElement
- PlayingTechnique
Constructors
- PlayingTechnique({required TechniqueType type, String? text})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
final
- type → TechniqueType
-
final
- xmlId ↔ String?
-
Identificador único MEI (
xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited