MetronomeMark class
Marca de metrônomo
- Inheritance
-
- Object
- MusicalElement
- MetronomeMark
Constructors
- MetronomeMark({DurationType? beatUnit, DurationType? secondBeatUnit, int? bpm, String? text})
Properties
- beatUnit → DurationType?
-
final
- bpm → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondBeatUnit → DurationType?
-
final
- text → String?
-
final
- xmlId ↔ String?
-
Identificador único MEI (
xml:id). Opcional; necessário para elementos referenciados por outros via atributos de ligação do MEI v5.getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited