TempoMark class

Representa a indicação de tempo/tempo

Inheritance

Constructors

TempoMark({required DurationType beatUnit, int? bpm, String? text, bool showMetronome = true})

Properties

beatUnit DurationType
final
bpm int?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showMetronome bool
final
text String?
final
xmlId String?
Identificador único MEI (xml:id). Opcional; required for elementos referenciados by other via atributos de ligação of the MEI v5.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited