MusicText class
Representa texto musical
- Inheritance
-
- Object
- MusicalElement
- MusicText
Constructors
Properties
- bold → bool?
-
final
- fontFamily → String?
-
final
- fontSize → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- italic → bool?
-
final
- placement → TextPlacement
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
final
- type → TextType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited