Syllable class
Representa uma sílaba de letra de música, correspondendo ao elemento
<syl> do MEI v5.
Syllable(text: 'can', type: SyllableType.initial) // "can-"
Syllable(text: 'ta', type: SyllableType.terminal) // "-ta"
Constructors
- Syllable({required String text, SyllableType type = SyllableType.single, bool italic = false})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- italic → bool
-
Indica se o texto deve ser exibido em itálico (ex.: extensão de vogal).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
Texto da sílaba.
final
- type → SyllableType
-
Tipo de conexão da sílaba (hifenização).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited