Verse class
Representa a verse de lyric, correspwherendo to the elemento <verse> of the MEI v5.
Suporta múltiplos verses numerados (@n) with syllables Syllable individuais.
Verse(
number: 1,
syllables: [
Syllable(text: 'A-', type: SyllableType.initial),
Syllable(text: 've', type: SyllableType.terminal),
],
)
- Inheritance
-
- Object
- MusicalElement
- Verse
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- language → String?
-
Idioma of the verse (MEI
@xml:lang), e.g., 'la', 'pt', 'en'.final - number → int
-
Number of the verse (MEI
@n). Default = 1.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
syllables
→ List<
Syllable> -
Syllables deste verse.
final
- xmlId ↔ String?
-
Identificador único MEI (
xml:id). Opcional; required for elementos referenciados by other via atributos de ligação of the MEI v5.getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited