TimeSignature class
Representa a fórmula de compasso.
- Inheritance
-
- Object
- MusicalElement
- TimeSignature
Constructors
- TimeSignature({required int numerator, required int denominator})
Properties
- denominator → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCompound → bool
-
Verifica se é um tempo composto
Tempo composto: numerador é múltiplo de 3 e maior que 3
Exemplos: 6/8, 9/8, 12/8
no setter
- isSimple → bool
-
Verifica se é um tempo simples
Tempo simples: numerador não é múltiplo de 3 (exceto 3 em si)
Exemplos: 2/4, 3/4, 4/4, 5/4, 7/8
no setter
- measureValue → double
-
Calcula o valor total permitido no compasso.
Fórmula: numerator × (1 / denominator)
no setter
- numerator → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited