TupletBracket class
Configuração do colchete de quiáltera
Constructors
- TupletBracket({double thickness = 0.125, double hookLength = 0.9, bool show = true, BracketSide side = BracketSide.stem, double slope = 0.0, double minDistanceFromNotes = 0.75})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hookLength → double
-
Comprimento dos ganchos nas extremidades
final
- minDistanceFromNotes → double
-
Distância mínima do colchete às notas (0.75 staff spaces)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- show → bool
-
Mostrar colchete
final
- side → BracketSide
-
Lado onde o colchete aparece
final
- slope → double
-
Inclinação do colchete (0 = horizontal)
Máximo recomendado: 1.75 staff spaces de diferença vertical
final
- thickness → double
-
Espessura da linha do colchete (0.125 staff spaces por padrão)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldShow(
List notes) → bool - Determina se o colchete deve ser mostrado com base nas notas
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited