allElements property
Shared elements of the bar followed by the elements of every voice, voices taken in ascending voice-number order.
This is the only iteration path that sees the whole content of a polyphonic measure.
Implementation
@override
Iterable<MusicalElement> get allElements sync* {
yield* elements;
for (final voice in sortedVoices) {
yield* voice.elements;
}
}