hasOpenEnd property
Whether the bracket has an open right end (no closing vertical line).
Defaults to false (closed bracket with a vertical line on the right).
Implementation
final bool hasOpenEnd;
Whether the bracket has an open right end (no closing vertical line).
Defaults to false (closed bracket with a vertical line on the right).
final bool hasOpenEnd;