ChantPlayback class
Result of building chant playback: the sequence to play/export plus a per-note notes timeline keyed back to the source elements.
Constructors
-
ChantPlayback({required MidiSequence sequence, required List<
ChantNoteTiming> notes}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
notes
→ List<
ChantNoteTiming> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequence → MidiSequence
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited